package com.diagbot.facade;

import com.diagbot.client.AIServiceClient;
import com.diagbot.client.bean.Response;
import com.diagbot.client.bean.ResponseData;
import com.diagbot.client.bean.SearchData;
import com.diagbot.dto.AIDTO;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.vo.AIVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * @Description: 调用AI服务业务实现
 * @author: gaodm
 * @time: 2018/10/25 10:09
 */
@Component
public class AIFacade {
    @Autowired
    private AIServiceClient aiServiceClient;

    /**
     * 调用ai接口业务逻辑
     *
     * @param aivo 搜索参数
     * @return AI接口返回结果
     */
    public AIDTO push(AIVO aivo, String type) {
        SearchData searchData = new SearchData();
        searchData.setAge(aivo.getAge());
        searchData.setSymptom(aivo.getSymptom());
        switch (aivo.getSex()) {
            case 1:
                searchData.setSex("M");
                break;
            case 2:
                searchData.setSex("F");
                break;
            default:
                throw new CommonException(CommonErrorCode.PARAM_ERROR, "不能输入男女以外的性别");
        }
        searchData.setFeatureType(type);
        searchData.setSysCode("1");
        switch (type) {
            case "1":
                searchData.setLength(10);
                break;
            case "7":
                searchData.setLength(2);
                break;
        }
        Response<ResponseData> res = aiServiceClient.bayesPageData(searchData);
        if (null == res || null == res.getData()) {
            throw new CommonException(CommonErrorCode.SERVER_IS_ERROR, "AI没有返回结果");
        }
        AIDTO aidto = new AIDTO();
        switch (type) {
            case "1":
                aidto.setItems(res.getData().getSymptom());
                break;
            case "7":
                aidto.setItems(res.getData().getDis());
                break;
        }
        return aidto;
    }
}
